//[mahjong-utils](../../../index.md)/[mahjongutils.yaku](../index.md)/[Yakus](index.md)/[RoundWind](-round-wind.md)

# RoundWind

[common]\
val [RoundWind](-round-wind.md): [Yaku](../-yaku/index.md)

场风
